@@ -17,6 +17,9 @@
 import { useEffect, useState } from 'react';
 import { useLocation, history } from 'umi';
 import querystring from 'query-string';
+import type { PageInfo } from '@ant-design/pro-table/lib/typing';
+import type { ActionType } from '@ant-design/pro-table';
+import type { MutableRefObject } from 'react';
 
 export default function usePagination() {
   const location = useLocation();
@@ -30,5 +33,14 @@ export default function usePagination() {
     history.replace(`${location.pathname}?page=${page}&pageSize=${pageSize}`);
   };
 
-  return { paginationConfig, savePageList };
+  const checkPageList = (ref: MutableRefObject<ActionType | undefined>) => {
+    const { current, pageSize, total } = ref.current?.pageInfo as PageInfo;
+    if (current > pageSize / total && current > 1) {
+      savePageList(paginationConfig.current - 1, paginationConfig.pageSize);
+    } else {
+      ref.current?.reload();
+    }
+  };
+
+  return { paginationConfig, savePageList, checkPageList };
 }
