@@ -19,4 +19,6 @@ export default {
   'page.plugin.list': 'Eklenti Listesi',
   'page.plugin.list.enabled': 'Aktif eklentilerin listesi',
   'page.plugin.market.config': 'Genel Eklenti Listesi',
+  'page.plugin.edit': 'Eklenti başarıyla yapılandırma',
+  'page.plugin.delete': 'Eklentiyi başarıyla kaldırın',
 };
